@@ -5,7 +5,6 @@
 # @File    : __init__.py.py
 
 
-import logging
 import os
 
 import pip
@@ -17,16 +16,8 @@ def package(package_name: list):
         for i in os.popen(f'pip list').readlines()[2:]
     ]
     exist_lst = []
-    logging.info(f'当前已安装：{current}')
     for i in package_name:
         if i not in current:
-            logging.info(f'正在安装：{i}')
             pip.main(['install', '-i', 'https://pypi.tuna.tsinghua.edu.cn/simple', i])
             exist_lst.append(i)
     return exist_lst
-
-
-from .crawler.proxy import GetProxy
-from .crawler.middleware import Proxy
-from .crawler.scheduler import ResetScheduler
-from .crawler import Forge
